from splent_framework.blueprints.base_blueprint import create_blueprint
from splent_framework.services.service_locator import register_service

from splent_io.splent_feature_profile.services import UserProfileService

profile_bp = create_blueprint(__name__)


def init_feature(app):
    register_service(app, "UserProfileService", UserProfileService)


def inject_context_vars(app):
    return {}



"""splent_feature_profile

Revision ID: 29f0c82ca134
Revises:
Create Date: 2026-03-21 18:47:37.323348

"""

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "29f0c82ca134"
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "user_profile",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("user_id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=100), nullable=False),
        sa.Column("surname", sa.String(length=100), nullable=False),
        sa.ForeignKeyConstraint(
            ["user_id"],
            ["user.id"],
        ),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("user_id"),
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("user_profile")
    # ### end Alembic commands ###
